==> odata-client-msgraph-beta-0.1.26-sources.jar: odata/msgraph/client/beta/complex/SynchronizationSecretKeyStringValuePair.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFields;

import java.util.Optional;

import odata.msgraph.client.beta.enums.SynchronizationSecret;

@JsonPropertyOrder({
    "@odata.type", 
    "key", 
    "value"})
@JsonInclude(Include.NON_NULL)
public class SynchronizationSecretKeyStringValuePair implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected ContextPath contextPath;

    @JacksonInject
    @JsonIgnore
    protected UnmappedFields unmappedFields;

    @JsonProperty("@odata.type")
    protected String odataType;

    @JsonProperty("key")
    protected SynchronizationSecret key;

    @JsonProperty("value")
    protected String value;

    protected SynchronizationSecretKeyStringValuePair() {
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.synchronizationSecretKeyStringValuePair";
    }

    @Property(name="key")
    @JsonIgnore
    public Optional<SynchronizationSecret> getKey() {
        return Optional.ofNullable(key);
    }

    public SynchronizationSecretKeyStringValuePair withKey(SynchronizationSecret key) {
        SynchronizationSecretKeyStringValuePair _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.synchronizationSecretKeyStringValuePair");
        _x.key = key;
        return _x;
    }

    @Property(name="value")
    @JsonIgnore
    public Optional<String> getValue() {
        return Optional.ofNullable(value);
    }

    public SynchronizationSecretKeyStringValuePair withValue(String value) {
        SynchronizationSecretKeyStringValuePair _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.synchronizationSecretKeyStringValuePair");
        _x.value = value;
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFields();
        }
        unmappedFields.put(name, value);
    }

    @Override
    @JsonIgnore
    public UnmappedFields getUnmappedFields() {
        return unmappedFields == null ? new UnmappedFields() : unmappedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builder() {
        return new Builder();
    }

    public static final class Builder {
        private SynchronizationSecret key;
        private String value;
        private ChangedFields changedFields = new ChangedFields();

        Builder() {
            // prevent instantiation
        }

        public Builder key(SynchronizationSecret key) {
            this.key = key;
            this.changedFields = changedFields.add("key");
            return this;
        }

        public Builder value(String value) {
            this.value = value;
            this.changedFields = changedFields.add("value");
            return this;
        }

        public SynchronizationSecretKeyStringValuePair build() {
            SynchronizationSecretKeyStringValuePair _x = new SynchronizationSecretKeyStringValuePair();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFields();
            _x.odataType = "microsoft.graph.synchronizationSecretKeyStringValuePair";
            _x.key = key;
            _x.value = value;
            return _x;
        }
    }

    private SynchronizationSecretKeyStringValuePair _copy() {
        SynchronizationSecretKeyStringValuePair _x = new SynchronizationSecretKeyStringValuePair();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields;
        _x.odataType = odataType;
        _x.key = key;
        _x.value = value;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("SynchronizationSecretKeyStringValuePair[");
        b.append("key=");
        b.append(this.key);
        b.append(", ");
        b.append("value=");
        b.append(this.value);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}

==> odata-client-msgraph-beta-0.2.1-sources.jar: odata/msgraph/client/beta/complex/SynchronizationSecretKeyStringValuePair.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Optional;

import odata.msgraph.client.beta.enums.SynchronizationSecret;

@JsonPropertyOrder({
    "@odata.type", 
    "key", 
    "value"})
@JsonInclude(Include.NON_NULL)
public class SynchronizationSecretKeyStringValuePair implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected ContextPath contextPath;

    @JacksonInject
    @JsonIgnore
    protected UnmappedFieldsImpl unmappedFields;

    @JsonProperty("@odata.type")
    protected String odataType;

    @JsonProperty("key")
    protected SynchronizationSecret key;

    @JsonProperty("value")
    protected String value;

    protected SynchronizationSecretKeyStringValuePair() {
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.synchronizationSecretKeyStringValuePair";
    }

    @Property(name="key")
    @JsonIgnore
    public Optional<SynchronizationSecret> getKey() {
        return Optional.ofNullable(key);
    }

    public SynchronizationSecretKeyStringValuePair withKey(SynchronizationSecret key) {
        SynchronizationSecretKeyStringValuePair _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.synchronizationSecretKeyStringValuePair");
        _x.key = key;
        return _x;
    }

    @Property(name="value")
    @JsonIgnore
    public Optional<String> getValue() {
        return Optional.ofNullable(value);
    }

    public SynchronizationSecretKeyStringValuePair withValue(String value) {
        SynchronizationSecretKeyStringValuePair _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.synchronizationSecretKeyStringValuePair");
        _x.value = value;
        return _x;
    }

    public SynchronizationSecretKeyStringValuePair withUnmappedField(String name, Object value) {
        SynchronizationSecretKeyStringValuePair _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builder() {
        return new Builder();
    }

    public static final class Builder {
        private SynchronizationSecret key;
        private String value;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        public Builder key(SynchronizationSecret key) {
            this.key = key;
            this.changedFields = changedFields.add("key");
            return this;
        }

        public Builder value(String value) {
            this.value = value;
            this.changedFields = changedFields.add("value");
            return this;
        }

        public SynchronizationSecretKeyStringValuePair build() {
            SynchronizationSecretKeyStringValuePair _x = new SynchronizationSecretKeyStringValuePair();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "microsoft.graph.synchronizationSecretKeyStringValuePair";
            _x.key = key;
            _x.value = value;
            return _x;
        }
    }

    private SynchronizationSecretKeyStringValuePair _copy() {
        SynchronizationSecretKeyStringValuePair _x = new SynchronizationSecretKeyStringValuePair();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.key = key;
        _x.value = value;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("SynchronizationSecretKeyStringValuePair[");
        b.append("key=");
        b.append(this.key);
        b.append(", ");
        b.append("value=");
        b.append(this.value);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}
